@@ -4,7 +4,6 @@ import argparse
 
 template = """#include <bits/stdc++.h>
 using namespace std;
-#define read(type) readInt<type>() // Fast read
 #define ll long long
 #define nL "\\n"
 #define pb push_back
@@ -27,6 +26,7 @@ int32_t main()
     cin.tie(NULL);
     int ttt; cin >> ttt;
     while(ttt--) {
+        cout << ttt << endl;
     }
     return 0;
 }"""
@@ -35,16 +35,10 @@ int32_t main()
 def cli():
     parser = argparse.ArgumentParser()
     parser.add_argument("filename", help="file to run")
-    parser.add_argument("-c", "--create", help="create file",
-                        action="store_true")
     args = parser.parse_args()
-
-    if args.create:
-        if os.path.exists(args.filename):
-            print("File already exists.")
-        else:
-            with open(args.filename, "w+") as f:
-                f.write(template)
+    if not os.path.exists(args.filename):
+        with open(args.filename, "w+") as f:
+            f.write(template)
     else:
         os.system(f"g++ {args.filename}")
         os.system(f"./a.out")
